# -*- coding: utf-8 -*-
from django.conf import settings
from django.core.management import call_command
from django.core.management.base import CommandError
from django.db import transaction

from thx.core.management.commands import ThxBaseCommand


class Command(ThxBaseCommand):
    help = "Load initial data"

    def add_arguments(self, parser):
        parser.add_argument("-d", "--dev", action="store_true", default=False, help="Load also `dev` data")

    def handle(self, *args, **options) -> None:
        try:
            self.load_data(dev=options["dev"])
            self.stdout.write("Load initial data: execution completed")
            self.logger.info("Load initial data: execution completed")
        except CommandError as e:
            self.stdout.write(self.style.ERROR(f"Load initial data: execution failed: {e}"))
            self.logger.error(e)

    @transaction.atomic
    def load_data(self, dev: bool = False) -> None:
        for app in getattr(settings, "THX_CORE_INIT_DATA_APPS", []):
            call_command("loaddata", settings.THX_CORE_INIT_DATA_FILE_NAME, app=app, verbosity=2)
            if dev:
                try:
                    call_command("loaddata", settings.THX_CORE_INIT_DATA_DEV_FILE_NAME, app=app, verbosity=2)
                except CommandError as e:
                    self.stdout.write(self.style.ERROR(f"{app}: {e}"))
