# -*- coding: utf-8 -*-
"""Database helper functions."""
from django.db import NotSupportedError
from django.db.models import Func, Value
from django.db.models.functions import JSONObject


class JSONBUpdate(Func):
    template = "%(jsonfield)s || %(expressions)s"

    def __init__(self, jsonfield: str, update_dict: dict):
        self.jsonfield = jsonfield
        super().__init__(self.as_jsonb_object(update_dict))

    def as_sql(self, compiler, connection, **extra_context):
        if not connection.features.has_json_object_function:  # pragma: no cover
            raise NotSupportedError(
                "%(class_name)s is not supported on this database backend." % {"class_name": self.__class__.__name__}
            )
        extra_context["jsonfield"] = self.jsonfield
        return super().as_sql(compiler, connection, **extra_context)

    def as_jsonb_object(self, update_dict):
        return JSONObject(**{
            key: self.as_jsonb_object(value) if isinstance(value, dict) else Value(value)
            for key, value in update_dict.items()
        })
